function [COMB]=COMBIN(XVAL)
//******************************************************************
//  Function to generate a set of all possible combinaisons of values in
//  XVAL.
//
//  Input arguments of the function :
//        XVAL  list of possible values of N parameters (list of size N)
//
//  Output arguments of the function :
//        UH    Unit hydrograph
//

//------ Validation of input variables -------
    ierr=execstr('N = lstsize(XVAL)','errcatch');
    if ierr<>0 then, error('XVAL is not a list (see function list)'); end      
    
//------ CORE CODE -------    

    // Size of the resulting matrix
    P=1;
    for i=1:N
        ni=size(XVAL(i),'*');
        if ni==0 then, ni=1; end;
        P = P*ni;
    end
    
    // Generation of the COMB matrix
    L = P;
    for p=1:N
	np=size(XVAL(p),'*');
	if np==0 then, np=1; end;
        // Length of the identical parameters
        L = L/np;
        for u=1:P/L
            uu = modulo(u,np);if uu==0 then, uu=np; end;
            COMB(p,(u-1)*L+1:u*L)= XVAL(p)(uu);
        end
    end
    
    
endfunction

