  function [Res]=CORRCROIS(u,v,DecalMax,varargin)
//******************************************************************
// Fonction permettant d'estimer le dcalage temporel entre 2 sries
// Resespondant  la Reslation croise maximale
//******************************************************************
// Paramtres :
//  u : Signal 1
//  v : Signal 2
//  DecalMax : Valeur maximale du dcalage
//  NoNegVal : Ne tient pas compte des valeurs ngatives (dfaut = %f);

//------ Validation of input variables -------
    if size(u,2)<>1&size(v,2)<>1      then, error('u or v are not column vector'); end;
    if size(u,1)<>size(v,1)           then, error('u and v do not have the same size'); end;
    if DecalMax<=0 | int(DecalMax)<> DecalMax then, error('DecalMax should be a positive integer'); end;

//------ Optional parameters -------
    [lhs,rhs] = argn();   // The following list attributes defaults parameters values if no other values are defined
    NBARGFIX = 3;

    NoNegVal = %f;      
    if rhs >= NBARGFIX+1 then, if varargin(1)<>'def' then,NoNegVal  = varargin(1); end;end;
    if NoNegVal<>%f & NoNegVal<>%t then, error('NoNegVal is not a boolean'); end;
    
// ---- Core function -------------------------

    // LAG
    if size(DecalMax,'*')==1 then
      LAG=-DecalMax:DecalMax;
    else
      LAG = DecalMax;
    end
    
    k=1;Res=[];
    for i=LAG
        // Storage of the lag value
        Res(k,1)=i;
        
        // Application of the lag on the series
        u_tp = u;
        v_tp = DECALVECT(v,i);
        
        if NoNegVal then
            ii = find(u_tp>=0 & v_tp>=0);
            u_tp = u_tp(ii);
            v_tp = v_tp(ii);
        end
  
        // Calculation of the correlation coefficient
        cov=corr(u_tp,v_tp,1);var1=corr(u_tp,u_tp,1);var2=corr(v_tp,v_tp,1);
        Res(k,2)=cov/sqrt(var1*var2);
        
        // Loop
        k=k+1;
    end


endfunction
