function [STAT]=GRAPH_BOX(DATA,varargin)
//******************************************************************
//  Function to generate graphs showing correlations in a set of
//  variables
//
//  Input arguments of the function :
//        DATA           Data to be plotted, matrix [NxP] with N = nb of value and P = Nb of variables
//        {opt. param. 1}  PLOT   Plot the graph or not (true/false)
//        {opt. param. 2}  CAT    Data organised by a category on the first column of the DATA matrix or not (true/false)
//        {opt. param. 3}  LEG	   Name of the variables (matrix of string [1xP]
//        {opt. param. 4}  FREQ   Frequency to use in boxplot drawing
//        {opt. param. 5}  EXPL   Explanation to be drawn on the boxplot or not (true/false)
//
//  Output arguments of the function :
//        STAT     Statistics on data
//******************************************************************************************

    Nserie = size(DATA,2); // Number of time series

//------ Optional parameters -------

    [lhs,rhs] = argn();   // The following list attributes defaults parameters values if no other values are defined
    NBARGFIX  = 1;

    PLOT=%t;
    if rhs >= NBARGFIX+1 then, if varargin(1)<>'def' then, PLOT  = varargin(1); end; end;
    
    CAT=%f;
    if rhs >= NBARGFIX+2 then, if varargin(2)<>'def' then, CAT  = varargin(2); end; end;
    if CAT & size(DATA,2)<>2 then, error('To use boxplots with categories, DATA should be a two column matrix'); end;
    if CAT then, CATLISTE=lex_sort(DATA(:,1),'unique');Nserie = size(CATLISTE,'*'); end; // Number of categories
    
    LEG = [];for s=1:Nserie, LEG=[LEG 'V'+string(s)]; end;
    if rhs >= NBARGFIX+3 then, if varargin(3)<>'def' then, LEG  = varargin(3); end; end;
    if size(LEG,2)<>Nserie then,  error('Wrong size of LEG (number of time series)'); end;
    LEG = string(LEG); // String conversion
    
    FREQ = [0.1,0.25,0.5,0.75,0.9];
    if rhs >= NBARGFIX+4 then, if varargin(2)<>'def' then, FREQ  = varargin(4); end; end;
    if size(FREQ,'*')<>5 then, error('Wrong size of FREQ'); end;

    EXPL = %T;
    if rhs >= NBARGFIX+5 then, if varargin(3)<>'def' then, EXPL  = varargin(5); end; end;
    if EXPL<>%F & EXPL<>%T then, error('EXPL is not a boolean'); end;

 //------ CODE CODE -------
  // Box parameters
  LARG_BOX = 0.6;
  LARG_LINE= 0.4;
  
  // Statistics
  STAT= [];NB_INDIV=[];
  if ~CAT then      
      STAT(6,:) = mean(DATA,'r'); // Means
      
      // Quantiles
      for ff=1:size(FREQ,'*')
          for nn=1:Nserie
              temp=%nan;
              ierr=execstr('temp=perctl(DATA(:,nn),FREQ(ff)*100);','errcatch'); 
              STAT(ff,nn)=temp(1); 
          end
      end
  else
      // loop over the categories
      for cc=1:Nserie
          icc=find(DATA(:,1)==CATLISTE(cc));
          NB_INDIV(cc)=size(icc,'*');
          LEG(cc)=string(CATLISTE(cc));

          // Mean
          STAT(6,cc)=mean(DATA(icc,2));

          // Quantiles
          for ff=1:size(FREQ,'*')
              temp=%nan;
              ierr=execstr('temp=perctl(DATA(icc,2),FREQ(ff)*100);','errcatch'); 
              STAT(ff,cc)=temp(1);
          end
       end
  end

  // Dimensions of the figure
  if PLOT then
      // boxplots
      plot(1:Nserie,STAT(6,:),'+'); // Means
      
      // MinMax
      MINMAX=[0.5,min(STAT(1,:)-0.25*(STAT(2,:)-STAT(1,:)));Nserie+0.5,max(STAT(5,:)+0.25*(STAT(5,:)-STAT(4,:)))];
      if find(isnan(MINMAX(:,2)))<>[] then
          MINMAX=[0,min(STAT(2,:)-0.25*(STAT(3,:)-STAT(2,:)));Nserie+0.5,max(STAT(4,:)+0.25*(STAT(4,:)-STAT(3,:)))];
      end
      gr=gca();gr.data_bounds=MINMAX;

      // Quantiles 0.25 and 0.75
      RECT = [(1:Nserie)'-LARG_BOX/2,STAT(4,:)',LARG_BOX*ones(Nserie,1),(STAT(4,:)-STAT(2,:))'];
      xrects(RECT');
      if EXPL then
          xstring(1-0.9*LARG_BOX/2,STAT(2,1),string(FREQ(2)));
          xstring(1-LARG_BOX/2,STAT(4,1),string(FREQ(4)));
      end
      
      // Median
      SEGS_Med_1x = [(1:Nserie)-LARG_BOX/4;(1:Nserie)+LARG_BOX/4]; // horizontal lines
      SEGS_Med_1y = [STAT(3,:);STAT(3,:)];
      xsegs(SEGS_Med_1x,SEGS_Med_1y);
      if EXPL then, xstring(1-0.9*LARG_BOX/2,STAT(3,1),'Med'); end;
      
      // Quantiles  0.1
      if find(isnan(STAT(1,:)))==[] then
          SEGS_Qt10_1x = [(1:Nserie)-LARG_LINE/2;(1:Nserie)+LARG_LINE/2]; // horizontal lines
          SEGS_Qt10_1y = [STAT(1,:);STAT(1,:)];
          xsegs(SEGS_Qt10_1x,SEGS_Qt10_1y);
          if EXPL then, xstring(1-LARG_LINE/2,STAT(1,1),string(FREQ(1))); end;

          SEGS_Qt10_2x = [1:Nserie;1:Nserie]; // Vertical lines
          SEGS_Qt10_2y = [STAT(1,:);STAT(2,:)];
          xsegs(SEGS_Qt10_2x,SEGS_Qt10_2y);
      end
      
      // Quantiles 0.9
      if find(isnan(STAT(5,:)))==[] then
          SEGS_Qt90_1x = [(1:Nserie)-LARG_LINE/2;(1:Nserie)+LARG_LINE/2]; // horizontal lines
          SEGS_Qt90_1y = [STAT(5,:);STAT(5,:)];
          xsegs(SEGS_Qt90_1x,SEGS_Qt90_1y);
          if EXPL then, xstring(1-LARG_LINE/2,STAT(5,1),string(FREQ(5))); end;

          SEGS_Qt90_2x = [1:Nserie;1:Nserie]; // Vertical lines
          SEGS_Qt90_2y = [STAT(5,:);STAT(4,:)];
          xsegs(SEGS_Qt90_2x,SEGS_Qt90_2y);
      end
      
      // xaxis
      gr.auto_ticks=['off','on'];gr.sub_ticks=[0,1];
      XTK=tlist(['ticks','locations','labels'],1:Nserie,LEG);
      gr.x_ticks=XTK;
            
      // Number of individuals in each categories
      if CAT then, for cc=1:Nserie, ...
          xstring(cc-0.3,MINMAX(1,2),'['+string(NB_INDIV(cc))+']'); end; end;
  end
    
endfunction






