function [ok]=GRAPH_DATE(TS,varargin)
//******************************************************************
//  Function to add date values in abscissae of time series graphs
//
//  Input arguments of the function :
//        TS         Time step increment of abscissae (expressed as [number.ts], ex 1.y = one year, 3.d=3 days)
//        LANG       Language (default = ENG, possible = FR)
//        D1         Initial date of the time series (format YYYYMMDDhhmm)
//        D2         Final date of the time series (format YYYYMMDDhhmm)
//
//  Output arguments of the function :
//        FichGraph     List of generated files
//******************************************************************************************
ok=%f;
//------ Validation of input variables -------
    //ierr=0;ierr=execstr('fig=get_figure_handle(f)','errcatch');
    //if ierr<>0 then, error('Problem with the figure number'); end;
    gr=gca();
    if gr.children==[] then, error('Empty figure, use a plotting command before');end;
      
    temp=tokens(TS,'.'); 
    if size(temp,'*')<>2 | (temp(2)<>'y'&temp(2)<>'m'&temp(2)<>'d') then, ...
      error('Wrong value of TS'); end;
    TSn=eval(temp(1)); TSt=temp(2);

    ierr=0;ierr=execstr('temp=gr.x_ticks(2);','errcatch');
    if ierr<>0 then, error('Problem with date extracting'); end;
    D1=c_CONVDATE(1,temp(1));D2=c_CONVDATE(1,temp($));
    if c_CONVDATE(0,D1)<0 | c_CONVDATE(0,D2)<0 then, error('Wrong values of D1 or D2'); end;
    
//------ Optional parameters -------

    [lhs,rhs] = argn();   // The following list attributes defaults parameters values if no other values are defined
    NBARGFIX  = 2;
    LANG='ENG';if rhs >= NBARGFIX+1 then, if varargin(1)<>'def' then, LANG=varargin(1);end;end; // Language

//------ Name of months -------
    MONTH = ['Jan' 'Feb' 'Mar' 'Apr' 'May' 'Jun' 'Jul' 'Aug' 'Sep' 'Oct' 'Nov' 'Dec']';
    if LANG=='FR' then,
      MONTH = ['Jan' 'Fev' 'Mar' 'Avr' 'Mai' 'Juin' 'Juil' 'Au' 'Sep' 'Oct' 'Nov' 'Dec']';      
    end

//------ CODE CODE -------
    // Generation of tick mark position

    if TSt=='y' then
        DT  = (int(D1/10^8):TSn:int(D2/10^8)+1)'*10^8+101*10^4; DTn = c_CONVDATE(0,DT); 
        // Generation of tick mark text
        DTt = msprintf('1 Jan %4d\n',int(DT*1e-8));
    end
    
    if TSt=='m' then
        DT  = 100*(int(D1/10^8):int(D2/10^8)+1)'*ones(1,12); 
        DT  = DT + ones(size(DT,1),1)*(1:12);DT=DT';DT=DT(1:$);
        DT  = DT(1:TSn:$)*10^6+10^4; 
        DTn = c_CONVDATE(0,DT);
        
        // Year and month
        temp=msprintf('%12.0f\n',DT);
        YE = part(temp,3:4);
        MON = MONTH(eval(part(temp,5:6)));
        
        // Generation of tick mark text
        DTt = msprintf('1 %3s %2s\n',MON,YE);        
    end
    
    if TSt=='d' then
        DTn  = (c_CONVDATE(0,D1):TSn:c_CONVDATE(0,D2))'; 
        DT=c_CONVDATE(1,DTn);

        // Year, month and days
        temp=msprintf('%12.0f\n',DT);
        YE = part(temp,3:4);
        MON = MONTH(eval(part(temp,5:6)));
        DAY = eval(part(temp,7:8));
                
        // Generation of tick mark text
        DTt = msprintf('%d %3s %2s\n',DAY,MON,YE);        
    end
        
    // Tick addition on the graph
    gr.auto_ticks=['off','on','on'];
    XTK=tlist(['ticks','locations','labels'],DTn,DTt);
    gr.x_ticks=XTK;
    gr.sub_ticks=[0,0];
    
    ok=%t;

endfunction






