function [TITRE,varargout]=IO_ENTETE(TITRECOL,NBCAR,varargin)
//******************************************************************
//  Function to generate a header of a numerical matrix to be printed
//  with fprintfMat
//
//  Input arguments of the function :
//        TITRECOL    Vector of string containing each column title
//        NBCAR       Number of caracters allowed for each column
//        NBDEC       Number of decimal for the number format
//
//  Output arguments of the function :
//        TITRE       String containing the header
//        FORMAT      String containing the number format

//------ Validation of input variables -------
    if size(TITRECOL,1)<>1 then, error('TITRECOL should be a line vector'); end;
    if size(NBCAR,1)<>1 & size(NBCAR,2)<>1 then, error('NBCAR should be a single value'); end;

//------ Optional parameters -------

    [lhs,rhs] = argn();   // The following list attributes defaults parameters values if no other values are defined

    NBDEC = 3;     if rhs >= 3 then, NBDEC  = varargin(1); end;
    NBSTR = 0;     if rhs >= 4 then, NBSTR  = varargin(2); end;
    HEADCHARAC = '#'; if rhs >= 5 then, HEADCHARAC = varargin(3); end;

//------ CORE FUNCTION CODE -------
    TITRE='';
    FORMAT='';

    for k=1:size(TITRECOL,2)
        if length(TITRECOL(k))>NBCAR then
            TITRECOL(k)=part(TITRECOL(k),1:NBCAR);
            warning('Title of the col. '+string(k)+' truncated');
        end
        TITRE = TITRE + msprintf('%'+string(NBCAR) + 's',TITRECOL(k)) + ' ';
        if NBSTR > 0 then, 
           if k<=NBSTR then, FORMAT=FORMAT+' %'+string(NBCAR)+'s'; else ...
              FORMAT=FORMAT+' %'+string(NBCAR)+'.'+string(NBDEC)+'f'; end;           
        else
    	      FORMAT=FORMAT+' %'+string(NBCAR)+'.'+string(NBDEC)+'f';
    	   end
    end
    FORMAT=part(FORMAT,2:length(FORMAT))+'\n';
    TITRE=HEADCHARAC + part(TITRE,2:length(TITRE));

//------ Outputs -------
    if lhs>=2 then, varargout(1)=FORMAT; end

    
endfunction

