function [ok]=IO_PRDATA(ChemFICH,FORMAT,DATA_NUM,DATA_TXT,varargin)
//******************************************************************
//  Function to print data in a text file
//
//  Input arguments of the function :
//       ChemFICH Path of the target file
//       FORMAT   Text/Numerical format
//       DATA_NUM Numerical data
//       DATA_TXT Text data
//       {Optional 1} HEADER     Content of header (vector of string)
//       {Optional 2} HEADCHARAC Character indicating header of the file 
//                    default = '#'
//       {Optional 3} CSV format ? (default = %f)
//
//  Output arguments of the function :
//       DATA_NUM Numerical data (matrix [NxP])
//       DATA_TXT Text (matrix [NxQ])

//------ Validation of input variables -------

    if FORMAT=='def' then, FORMAT = strsubst(string(zeros(1,size(DATA_TXT,2))),'0','%8s')+' '+...
                                    strsubst(string(zeros(1,size(DATA_NUM,2))),'0','%8.2f'); end;
    NBvar=size(strindex(FORMAT,'%'),'*');
    if NBvar==0 then, error('No % symbol in FORMAT'); end;
    if part(FORMAT,length(FORMAT)-1:length(FORMAT))<>'\n' then, FORMAT=FORMAT+'\n'; end;
    
//------ Optional parameters -------
    [lhs,rhs] = argn();
    NBARGFIX = 4;
    HEADER = [];      if rhs >= NBARGFIX+1 & varargin(1)<>'def' then, HEADER = varargin(1); end;    
    HEADCHARAC = '#'; if rhs >= NBARGFIX+2 & varargin(2)<>'def' then, HEADCHARAC = varargin(2); end;
    if NBvar<>size(DATA_NUM,2)+size(DATA_TXT,2) then, error('Problems with FORMAT and size of DATA_NUM/DATA_TXT'); end;

    CSVFORMAT = %f; if rhs >= NBARGFIX+3 then, CSVFORMAT = varargin(3); end;

//------ CORE FUNCTION CODE -------
    //warning('1. FORMAT arg: Do not include special character like s, d, f, c, % in format apart from format description !');
    //warning('2. FORMAT arg: Group all string format at the beginning  !');
    
    // Open the file and get lines
    ierr=0;
    ierr=execstr('f=mopen('+code2str(53)+ChemFICH+code2str(53)+','+code2str(53)+'w'+code2str(53)+')','errcatch');
    if ierr<>0 then, error('Problem with file opening'); quit; end;
 
    // Prints number of columns
    mfprintf(f,'# S%2s N%2s\n',part(string(1000+size(DATA_TXT,2)),3:4),part(string(1000+size(DATA_NUM,2)),3:4));
    
    // Prints header lines
    if HEADER<>[] then
        Txt_HEADER(find(part(HEADER,1)<>HEADCHARAC))=HEADCHARAC + ' ' + HEADER(find(part(HEADER,1)<>HEADCHARAC));
        Txt_HEADER(find(part(HEADER,1)==HEADCHARAC))=HEADER(find(part(HEADER,1)==HEADCHARAC));
        mfprintf(f,'%s\n',Txt_HEADER);
    else
        mfprintf(f,'%s ',HEADCHARAC);
        if size(DATA_NUM,2)+size(DATA_TXT,2)>1 then, mfprintf(f,' V%3.3d,',(1:size(DATA_NUM,2)+size(DATA_TXT,2)-1)');end;
        mfprintf(f,' V%3.3d',size(DATA_NUM,2)+size(DATA_TXT,2));
        mfprintf(f,'\n');
    end
    
    // CSV format
    if CSVFORMAT then, FORMAT = strsubst(FORMAT,'%',',%'); FORMAT = strsubst(FORMAT,' ','');..
      FORMAT = part(FORMAT,2:length(FORMAT)); end;     
      
    // Prints data
    if DATA_NUM<>[] & DATA_TXT<>[] then
        
        // Format for string data
        temp = tokens(FORMAT,'%');
        FORMAT_TXT=[];
        for i=1:size(DATA_TXT,2)
            tpFormat = '%' + temp(i); 
            FORMAT_TXT=FORMAT_TXT + tpFormat; 
        end
        FORMAT_TXT=FORMAT_TXT + ' %s\n';
        
        // Format for numerical data
        FORMAT_NUM=[];
        for i=size(DATA_TXT,2)+1:size(DATA_NUM,2)+size(DATA_TXT,2)
            tpFormat = '%' + temp(i); 
            FORMAT_NUM=FORMAT_NUM + tpFormat; 
            
        end

        mfprintf(f,FORMAT_TXT,[DATA_TXT msprintf(FORMAT_NUM,DATA_NUM)]);
    end

    if DATA_NUM<>[] & DATA_TXT==[] then
        mfprintf(f,FORMAT,DATA_NUM);
    end

    if DATA_TXT<>[] & DATA_NUM==[] then
        mfprintf(f,FORMAT,DATA_TXT);
    end

    mclose(f);
    ok=1;

endfunction

