function [Lines]=IO_PRLATEX(ChemFICH,DATA_NUM,DATA_TXT,varargin)
//******************************************************************
//  Function to print a latex table in a file
//
//  Input arguments of the function :
//       ChemFICH Path of the target file
//       DATA_NUM Numerical data (matrix [NxP])
//       DATA_TXT Text data (matrix [NxQ])
//       TITLES   Column titles (vector [P+Q])
//       NBDEC    Number of decimal to write numbers
//       CAPTION  Table caption
//       TABCODE  Latex table reference
//
//------ Validation of input variables -------

    if size(DATA_NUM,1)<>size(DATA_TXT,1) then, error('DATA_NUM and DATA_TXT do not have the same number of rows'); end;
    
//------ Optional arguments -------    

    [lhs,rhs] = argn();   // The following list attributes defaults parameters values if no other values are defined
    NBARGFIX = 3;

    TYPE = 'NORMAL';      
    if rhs >= NBARGFIX+1 then, if varargin(1)<>'def' then,TYPE  = varargin(1);end; end;
    if TYPE<>'NORMAL' & TYPE<>'LONG' then, error('TYPE should be either NORMAL or LONG'); end;

    NBDEC = ones(1,size(DATA_NUM,2));      
    if rhs >= NBARGFIX+2 then, if varargin(2)<>'def' then,NBDEC  = varargin(2);end; end;
    if size(NBDEC,'*')<>size(DATA_NUM,2) then, error('Wrong size of NBDEC'); end;

    TITLES=msprintf('C%d\n',(1:size(DATA_TXT,2)+size(DATA_NUM,2))')';
    if rhs >= NBARGFIX+3 then, if varargin(3)<>'def' then,TITLES  = varargin(3);end; end;
    if size(TITLES,2)<>size(DATA_NUM,2)+size(DATA_TXT,2) then, error('Wrong number of TITLES'); end;

    CAPTION = 'The table';      
    if rhs >= NBARGFIX+4 then, if varargin(4)<>'def' then,CAPTION  = varargin(4);end; end;
    if size(CAPTION,'*')<>1 then, error('Wrong size of CAPTION'); end;
    
    TABCODE = 'tab:';      
    if rhs >= NBARGFIX+5 then, if varargin(5)<>'def' then,CAPTION  = varargin(5);end; end;
    if size(TABCODE,'*')<>1 then, error('Wrong size of TABCODE'); end;

//------ CORE FUNCTION CODE -------    
    // Open the file
    ierr=0;
    ierr=execstr('f=mopen('+code2str(53)+ChemFICH+code2str(53)+','+code2str(53)+'w'+code2str(53)+');','errcatch');
    if ierr<>0 then, error('Problem with file opening'); quit; end;
 
    // Format 
    Fc='';
    for c=1:size(DATA_TXT,2), Fc = Fc + '%s & '; end;  Ft=Fc;
    for c=1:size(DATA_NUM,2)-1, Fc = Fc + '%6.'+string(NBDEC(c))+'f & '; Ft = Ft + '%s & ';end;
    Ft = Ft + '%s \\ \n';Fc = Fc + '%6.'+string(NBDEC(size(DATA_NUM,2)))+'f \\ \n';

    // Latex table column descriptor (centered text)
    colDesc = strcat(part(msprintf('%3dc\n',(1:size(TITLES,2))'),4)');

    // Build the latex table
    if TYPE=='LONG' then
        Lines = ['\begin{center}';strcat('\begin{longtable}{'+stripblanks (colDesc)+'}');'\hline'];
        Lines = [Lines;msprintf(Ft,TITLES);'\hline';'\endhead'];
        Lines = [Lines;msprintf(Fc,DATA_TXT,DATA_NUM)];    
        Lines = [Lines;'\hline';'\caption{'+CAPTION+'}';...
            '\label{'+TABCODE+'}';'\end{longtable}';'\end{center}'];
    else
        Lines = ['\begin{table}';'\center';strcat('\begin{tabular}{'+stripblanks (colDesc)+'}');'\hline'];
        Lines = [Lines;msprintf(Ft,TITLES);'\hline'];
        Lines = [Lines;msprintf(Fc,DATA_TXT,DATA_NUM)];    
        Lines = [Lines;'\hline';;'\end{tabular}';'\caption{'+CAPTION+'}';...
            '\label{'+TABCODE+'}';'\end{table}'];    
    end
  
    // Print in the file and close 
    mfprintf(f,'%s\n',Lines);    
    mclose(f);
    ok=1;

endfunction

