function [DATA_NUM,varargout]=IO_READDATA(ChemFICH,varargin)
//******************************************************************
//  Function to read data from a text file
//
//  Input arguments of the function :
//       ChemFICH Path of the target file
//       FORMAT   Text/Numerical format
//       {Optional 1} HEADCHARAC Character indicating header of the file 
//                    default = '#'
//
//  Output arguments of the function :
//       DATA_NUM Numerical data (matrix [NxP])
//       DATA_TXT Text (matrix [NxQ])
//
//  BUG pour les gros fichiers horaires
//  Prvoir une utilisation de fscanfMat pour le 100% numrique
//
//------ Validation of input variables -------
    NVARMAX = 30; // Maximum number of variable in the data file
    NVARNUMMAX = 99; // Maximum number of numerical variables in the data file

//------ Optional parameters -------

    [lhs,rhs] = argn();
    NBARGFIX = 1;    
    FORMATini='*';if rhs >= NBARGFIX+1 then, if varargin(1)<>'def' then, FORMATini = varargin(1); end; end;
    HEADCHARAC = '#'; if rhs >= NBARGFIX+2 then, HEADCHARAC = varargin(2); end;

//------ CORE FUNCTION CODE -------
    //warning('Do not include special character like s, d, f, c, % in format apart from format description !');
    ierr=0;
    ierr=execstr('[d,head]=fscanfMat(ChemFICH);','errcatch');
    temp=[];if ierr==0 then, temp=tokens(head(1),' '); end;

    if ierr==0 & (temp(2)=='S00'|temp==[]) then // IF to try if fscanfMat can read the file
        DATA_TXT=[];
        DATA_NUM=d;
        HEAD=[];if head<>'' then HEAD=head(2:$); end;
    else
          // Open the file and get lines
        ierr=0;
        ierr=execstr('f=mopen('+code2str(53)+ChemFICH+code2str(53)+','+code2str(53)+'r'+code2str(53)+')','errcatch');
        if ierr<>0 then, error('Problem with file opening'); quit; end;
        Txt = mgetl(f)
        mclose(f);

        // Build format
        if FORMATini<>'*' & part(Txt(1),1:3)=='# S' then
            Txt=Txt(2:$); 
            temp = tokens(FORMATini,' ');
            NBS=0;NBN=0;
            for col=1:size(temp,'*')
              if part(temp(col),length(temp(col)))=='s' | part(temp(col),length(temp(col)))=='c' then, NBS=NBS+1; end;
              if part(temp(col),length(temp(col)))=='f' | part(temp(col),length(temp(col)))=='d' then, NBN=NBN+1; end;
            end
        end
        if FORMATini=='*' & part(Txt(1),1:3)=='# S' then
            temp=tokens(Txt(1),' ');Txt=Txt(2:$);
            NBS = eval(part(temp(2),2:3));
            NBN = eval(part(temp(3),2:10));
            if NBS>NVARMAX then, error(msprintf('Too many string variables (%d > %d)',NBS,NBVARMAX)); quit; end;
            if NBN>NVARNUMMAX then, error(msprintf('Too many numerical variables (%d > %d)',NBN,NBVARNUMMAX)); quit; end;
            FORMATini='';
            for col=1:NBS, FORMATini=FORMATini+' %s'; end;
            for col=1:NBN, FORMATini=FORMATini+' %f'; end;
        end

        if part(FORMATini,1)==' ' then, FORMATini=part(FORMATini,2:length(FORMATini)); end;
        FORMATtok = tokens(FORMATini,'%');
        NBvar=NBS+NBN;
        FORMAT='';FORMAT2='';
        if NBvar==0 then, error('No % symbol in FORMAT'); end;

        FORMAT=''; // Format classique
        for v=1:NBvar, FORMAT = FORMAT + '%' + FORMATtok(v); end;
        FORMAT2='';v=1; // Seulement les variables text
        while FORMATtok(v)=='s ' & v<=NBvar, FORMAT2 = FORMAT2 + '%' + FORMATtok(v);v=v+1; end;// Solution quand on a + de 30 variables

        if FORMAT<>'' then, if part(FORMAT,length(FORMAT)-1:length(FORMAT))=='\n' then, FORMAT=part(FORMAT,1:length(FORMAT)-2); end;end;
        if FORMAT2<>'' then, if part(FORMAT2,length(FORMAT2)-1:length(FORMAT2))=='\n' then, FORMAT2=part(FORMAT2,1:length(FORMAT2)-2); end;end;

        // Eliminates header lines
        i=0;
        while part(Txt(i+1),1)==HEADCHARAC then, i=i+1; end;
        HEAD = Txt(1:i);
        Txt = Txt(i+1:$);

        //Read column names if exist
        NAMECOL=tokens(HEAD($),' ');
        NAMECOL(1)=part(NAMECOL(1),2:length(NAMECOL(1)));

        // Build the instruction to be passed to msscanf
        // LISTVAR is the string <V1,V2,...> (LISTVAR2 contains all the variables)
        // TYPE indicates if the variable is numerical or text

        LISTVAR='';TYPE=[];LISTVAR2='';nb2=0;
        for v=1:NBvar
            // Variable list
            if v<=NVARMAX then, LISTVAR = LISTVAR + 'V' + string(v) + ','; end;
            if v<=NBS then, LISTVAR2 = LISTVAR2 + 'V' + string(v) + ','; end;

            // Variable type (text or numerical)
            if strindex(FORMATtok(v),'c')<>[] | strindex(FORMATtok(v),'s')<>[] then, ...
            TYPE(v)=1; else TYPE(v)=0; end;

        end
        LISTVAR=part(LISTVAR,1:length(LISTVAR)-1); // Toutes les variables
        LISTVAR2=part(LISTVAR2,1:length(LISTVAR2)-1); // Variables

        // Execute msscanf ou fscanfMat suivant les cas
        if NBvar<=NVARMAX & NBS>0
            ierr=execstr('[n,'+LISTVAR+']=msscanf(-1,Txt,FORMAT)','errcatch');
            if ierr<>0 then, error('Problem with msscanf instruction, use simple format like %s %f %d'); quit; end;

        elseif NBS>0 & NBS<=NVARMAX & NBvar>NVARMAX
            warning('High number of variables (>'+string(NVARMAX)+'), separate scan of text and numerical variables.'+ ...
                              ' Temporary printing in '+TMPDIR+'.');
            // Scan des variables texte
            ierr=execstr('[n,'+LISTVAR2+']=msscanf(-1,Txt,FORMAT2)','errcatch');
            if ierr<>0 & LISTVAR2<>'' then, error('Problem with msscanf instruction, use simple format like %s %f %d'); quit; end;

            // Construction d'un autre fichier texte ne contenant que les donnes numriques (on limine les donnes texte)
            execstr('nbCtxt = strindex(Txt(1),V'+string(NBS)+'(1))+length(V'+string(NBS)+'(1));');
            Txt2=part(Txt,nbCtxt:length(Txt(1)));

            // Impression dans un fichier txt temporaire des donnes numriques
            f2=mopen(TMPDIR+'\HYDROGR.IO_READDATA.temp.txt','w');
            mfprintf(f2,'%s\n',Txt2);
            mclose(f2);
        end

        // Group text data and numerical data in unique matrices
        VARTXT = find(TYPE==1);DATA_TXT=[];
        for v=1:size(VARTXT,'*')
            execstr('DATA_TXT=[DATA_TXT V'+string(VARTXT(v))+'];');
        end

        VARNUM = find(TYPE==0);DATA_NUM=[];
        if NBvar<=NVARMAX & NBS>0
            for v=1:size(VARNUM,'*')
                execstr('DATA_NUM=[DATA_NUM V'+string(VARNUM(v))+'];');
            end
        elseif NBS>0 & NBS<=NVARMAX & NBvar>NVARMAX
            DATA_NUM = fscanfMat(TMPDIR+'\HYDROGR.IO_READDATA.temp.txt');
        end

    end // End of fscanfMat IF
    
//------ Output -------    
    if lhs>=2 then, varargout(1) = DATA_TXT; end;
    if lhs>=3 then, varargout(2) = NAMECOL; end;    
    if lhs>=4 then, varargout(3) = HEAD; end;
    
endfunction

